@@ -24,12 +24,11 @@ setClass("kegg_module",
     )
 )
 
-#' @importFrom GetoptLong qqcat
 setMethod("show",
     signature(object="kegg_module"),
     function(object) {
-        qqcat("@{object@ID}\n")
-        qqcat("@{object@name}\n")
+        cat(object@ID,"\n")
+        cat(object@name,"\n")
     }
 )
 
